import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:vitalapp/architecture/utils/advance_debounce.dart';
import 'package:vitalapp/architecture/utils/prompt_box.dart';
import 'package:vitalapp/architecture/values/features.dart';
import 'package:vitalapp/components/button.dart';
import 'package:vitalapp/components/side_nav/defines.dart';
import 'package:vitalapp/global.dart';
import 'package:vitalapp/pages/patient/create/controller.dart';
import 'package:vitalapp/pages/patient/create/widgets/area.dart';
import 'package:vitalapp/pages/patient/create/widgets/crowd_label.dart';
import 'package:vitalapp/pages/patient/create/widgets/patient_info.dart';
import 'package:vitalapp/store/store.dart';
import 'package:fis_common/helpers/color.dart';

class QuickCreatePatientPage extends GetView<CreatePatientController> {
  const QuickCreatePatientPage({super.key});

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Row(
          children: [
            if (Store.user.hasFeature(FeatureKeys.IdCardPhotoOCR) ||
                Store.user.hasFeature(FeatureKeys.IDCardReader))
              Expanded(
                flex: 1,
                child: Container(
                  decoration: BoxDecoration(
                    border: Border(
                      right: BorderSide(
                        color: Colors.grey.shade300,
                      ),
                    ),
                  ),
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      if (Store.user.hasFeature(FeatureKeys.IdCardPhotoOCR))
                        _buildClickCard(
                          Icons.perm_contact_cal_rounded,
                          '拍照识别',
                          () {
                            if (!kIsOnline) {
                              PromptBox.toast("当前为离线模式，不支持此功能");
                              return;
                            }
                            advanceDebounce(
                              controller.onIdCardScanClicked,
                              "PatientCreate.OnIdCardScanClicked",
                              1500,
                            );
                          },
                        ),
                      if (Store.user.hasFeature(FeatureKeys.IdCardPhotoOCR))
                        const SizedBox(
                          height: 80,
                        ),
                      if (Store.user.hasFeature(FeatureKeys.IDCardReader))
                        _buildClickCard(
                          Icons.chrome_reader_mode,
                          '读卡识别',
                          () {
                            advanceDebounce(
                              controller.onReadCardClicked,
                              "PatientCreate.OnReadCardClicked",
                              1500,
                            );
                          },
                        ),
                    ],
                  ),
                ),
              ),
            Expanded(
              flex: 2,
              child: PatientInfo(),
            ),
          ],
        ),
        // VSideNavView(
        //   // navId: NavIds.CREATE,
        //   items: _buildItems(),
        // ),
        Positioned(
          bottom: 8,
          left: 200,
          right: 200,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: [
              VButton(
                label: "保存",
                onTap: () {
                  controller.saveAndBack();
                },
              ),
            ],
          ),
        ),
      ],
    );
  }

  Widget _buildClickCard(
    IconData icon,
    String textString,
    VoidCallback voidCallback,
  ) {
    return Material(
      // color: Colors.blueAccent,

      borderRadius: const BorderRadius.all(
        Radius.circular(8),
      ),
      child: InkWell(
        onTap: () => voidCallback.call(),
        borderRadius: const BorderRadius.all(
          Radius.circular(8),
        ),
        child: Stack(
          children: [
            Container(
              padding: const EdgeInsets.symmetric(
                vertical: 50,
                horizontal: 80,
              ),
              // margin: const EdgeInsets.symmetric(horizontal: 50),
              decoration: BoxDecoration(
                borderRadius: const BorderRadius.all(
                  Radius.circular(8),
                ),
                gradient: LinearGradient(
                  colors: [
                    // Color.fromRGBO(59, 188, 255, 1),
                    // Color.fromRGBO(44, 120, 229, 1),
                    Colors.blue,
                    FColorHelper.mixColor(Colors.white, Colors.blue, 50),
                  ],
                  begin: Alignment.topLeft,
                  end: Alignment.bottomRight,
                ),
              ),
              child: Text(
                textString,
                style: const TextStyle(
                  fontSize: 20,
                  color: Colors.white,
                ),
              ),
            ),
            Positioned(
              top: 10,
              left: 10,
              child: Icon(
                icon,
                color: Colors.white,
                size: 40,
              ),
            ),
          ],
        ),
      ),
    );
  }

  VSideNavMenuItem _buildCreateManualRecord() {
    return VSideNavMenuItem(
      title: "手动建档",
      icon: Icon(Icons.edit_document, color: Colors.grey.shade700),
      pageBuilder: (_) => _buildInterval(
        PatientInfo(),
      ),
    );
  }

  VSideNavMenuItem _buildIDReaderRecord() {
    return VSideNavMenuItem(
      title: "读卡建档",
      icon: Icon(Icons.chrome_reader_mode, color: Colors.grey.shade700),
      onTap: () {
        controller.onReadCardClicked();
      },
    );
  }

  VSideNavMenuItem _buildScanIdCardRecord() {
    return VSideNavMenuItem(
      title: "身份证识别",
      icon: Icon(Icons.perm_contact_cal_rounded, color: Colors.grey.shade700),
      onTap: () {
        if (!kIsOnline) {
          PromptBox.toast("当前为离线模式，不支持此功能");
          return;
        }
        controller.onIdCardScanClicked();
      },
    );
  }

  VSideNavMenuItem _buildFaceIdLogin() {
    return VSideNavMenuItem(
      title: "人脸识别",
      icon: Icon(Icons.sensor_occupied, color: Colors.grey.shade700),
      onTap: () {
        if (!kIsOnline) {
          PromptBox.toast("当前为离线模式，不支持此功能");
          return;
        }
        controller.onFaceIdLoginClicked();
      },
    );
  }

  List<VSideNavMenuItem> _buildItems() {
    final items = <VSideNavMenuItem>[];
    items.add(_buildCreateManualRecord());

    if (Store.user.hasFeature(FeatureKeys.IDCardReader)) {
      items.add(_buildIDReaderRecord());
    }
    if (Store.user.hasFeature(FeatureKeys.FaceRecognition)) {
      items.add(_buildScanIdCardRecord());
    }
    if (Store.user.hasFeature(FeatureKeys.FaceRecognition)) {
      items.add(_buildFaceIdLogin());
    }
    // items.add(_buildLogOutItem());
    // items.add(_buildSignatureItem());
    // items.add(_buildAboutItem());
    return items;
  }

  VSideNavMenuItem _buildSignatureItem() {
    return VSideNavMenuItem(
      title: "服务信息",
      icon: Icon(Icons.edit_document, color: Colors.grey.shade700),
      pageBuilder: (_) => _buildInterval(
        const Area(),
      ),
    );
  }

  VSideNavMenuItem _buildAboutItem() {
    return VSideNavMenuItem(
      title: "人群分类",
      isRequired: true,
      icon: Icon(Icons.info_outline, color: Colors.grey.shade700),
      pageBuilder: (_) => _buildInterval(
        const CrowdLabelView(),
      ),
    );
  }

  VSideNavMenuItem _buildLogOutItem() {
    return VSideNavMenuItem(
      title: "个人信息",
      icon:
          Icon(Icons.medical_information_outlined, color: Colors.grey.shade700),
      pageBuilder: (_) => _buildInterval(
        PatientInfo(),
      ),
      // route: VRouteSetting(
      //   "/patient_info_panel",
      //   () => const PatientInfo(),
      //   binding: BindingsBuilder(
      //     () {
      //       Get.lazyPut(() => CreatePatientController());
      //     },
      //   ),
      // ),
      // shouldRearrage: true, // TODO: 调整样式后启用
    );
  }

  Widget _buildInterval(Widget child) {
    return Padding(
      padding: const EdgeInsets.symmetric(
        horizontal: 16,
      ),
      child: child,
    );
  }
}
